@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2024 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -15,12 +15,21 @@
 #define TIG_STRING_H
 
 #include "tig/tig.h"
-#include "tig/string.h"
 
 /*
  * Strings.
  */
 
+#if defined(__APPLE__)
+/* See COMPATIBILITY in isspace(3). */
+#define isalnum(c) iswalnum(btowc(c))
+#define iscntrl(c) iswcntrl(btowc(c))
+#define isdigit(c) iswdigit(btowc(c))
+#define ispunct(c) iswpunct(btowc(c))
+#define isspace(c) iswspace(btowc(c))
+#define isxdigit(c) iswxdigit(btowc(c))
+#endif
+
 #define prefixcmp(str1, str2) \
 	strncmp(str1, str2, STRING_SIZE(str2))
 
