@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2024 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -90,6 +90,9 @@ blame_open(struct view *view, enum open_flags flags)
 			opt_cmdline_args = NULL;
 		}
 
+		if (opt_commit_order == COMMIT_ORDER_REVERSE)
+			argv_append(&opt_blame_options, "--reverse");
+
 		/*
 		 * flags (like "--max-age=123") and bottom limits (like "^foo")
 		 * will be passed as-is, and retained even if we re-blame from
@@ -125,7 +128,7 @@ blame_open(struct view *view, enum open_flags flags)
 
 	if (!view->env->file[0] && opt_file_args && !opt_file_args[1]) {
 		const char *ls_tree_argv[] = {
-			"git", "ls-tree", "-d", "-z", *view->env->ref ? view->env->ref : view->env->commit, opt_file_args[0], NULL
+			"git", "ls-tree", "-d", "-z", *view->env->ref ? view->env->ref : "HEAD", opt_file_args[0], NULL
 		};
 		char buf[SIZEOF_STR] = "";
 
@@ -352,7 +355,7 @@ blame_go_forward(struct view *view, struct blame *blame, bool parent)
 	const char *filename = parent ? commit->parent_filename : commit->filename;
 
 	if (!*id && parent) {
-		report("The selected commit has no parents");
+		report("The selected commit has no parents with this file");
 		return;
 	}
 
@@ -454,6 +457,10 @@ blame_request(struct view *view, enum request request, struct line *line)
 		open_main_view(view, OPEN_RELOAD);
 		break;
 
+	case REQ_VIEW_BLOB:
+		string_ncopy(view->env->file, blame->commit->filename, strlen(blame->commit->filename));
+		return request;
+
 	default:
 		return request;
 	}
@@ -466,14 +473,18 @@ blame_select(struct view *view, struct line *line)
 {
 	struct blame *blame = line->data;
 	struct blame_commit *commit = blame->commit;
+	const char *text = blame->text;
 
 	if (!commit)
 		return;
 
-	if (string_rev_is_null(commit->id))
+	if (string_rev_is_null(commit->id)) {
 		string_ncopy(view->env->commit, "HEAD", 4);
-	else
+		string_format(view->ref, "%s", commit->filename);
+	} else {
 		string_copy_rev(view->env->commit, commit->id);
+		string_format(view->ref, "%s changed %s", commit->id, commit->filename);
+	}
 
 	if (strcmp(commit->filename, view->env->file))
 		string_format(view->env->file_old, "%s", commit->filename);
@@ -481,6 +492,8 @@ blame_select(struct view *view, struct line *line)
 		view->env->file_old[0] = '\0';
 
 	view->env->lineno = view->pos.lineno + 1;
+	string_ncopy(view->env->text, text, strlen(text));
+	view->env->blob[0] = 0;
 }
 
 static struct view_ops blame_ops = {
