@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2024 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -340,7 +340,7 @@ open_trace(int devnull, const char *argv[])
 bool
 io_trace(const char *fmt, ...)
 {
-	static FILE *trace_out; /* Intensionally leaked. */
+	static FILE *trace_out; /* Intentionally leaked. */
 	va_list args;
 	int retval;
 
@@ -418,6 +418,11 @@ io_exec(struct io *io, enum io_type type, const char *dir, char * const env[], c
 				close(pipefds[0]);
 			if (pipefds[1] != -1)
 				close(pipefds[1]);
+		} else {
+			if (custom != -1) {
+				dup2(custom, STDIN_FILENO);
+				close(custom);
+			}
 		}
 
 		if (dir && *dir && chdir(dir) == -1)
@@ -431,6 +436,13 @@ io_exec(struct io *io, enum io_type type, const char *dir, char * const env[], c
 					putenv(env[i]);
 		}
 
+		signal(SIGHUP, SIG_DFL);
+		signal(SIGINT, SIG_DFL);
+		signal(SIGPIPE, SIG_DFL);
+#ifdef DEBUG
+		signal(SIGSEGV, SIG_DFL);
+#endif
+
 		execvp(argv[0], (char *const*) argv);
 
 		close(STDOUT_FILENO);
@@ -463,9 +475,9 @@ io_run_bg(const char **argv, const char *dir)
 }
 
 bool
-io_run_fg(const char **argv, const char *dir)
+io_run_fg(const char **argv, const char *dir, int fd)
 {
-	return io_complete(IO_FG, argv, dir, -1);
+	return io_complete(IO_FG, argv, dir, fd);
 }
 
 bool
