@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2024 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -319,7 +319,7 @@ parse_step(double *opt, const char *arg)
 {
 	int value = atoi(arg);
 
-	if (!value && !isdigit(*arg))
+	if (!value && !isdigit((unsigned char)*arg))
 		return error("Invalid double or percentage");
 
 	*opt = value;
