@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2024 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -687,7 +687,6 @@ void
 update_view_title(struct view *view)
 {
 	WINDOW *window = view->title;
-	struct line *line = &view->line[view->pos.lineno];
 	unsigned int view_lines, lines;
 	int update_increment = view_has_flags(view, VIEW_LOG_LIKE | VIEW_GREP_LIKE)
 			       ? 100
@@ -707,16 +706,18 @@ update_view_title(struct view *view)
 		wprintw(window, " %s", view->ref);
 	}
 
-	if (!view_has_flags(view, VIEW_CUSTOM_STATUS) && view_has_line(view, line) &&
-	    line->lineno) {
-		wprintw(window, " - %s %u of %zu",
-					   view->ops->type,
-					   line->lineno,
-					   MAX(line->lineno,
-					       view->pipe
-					       ? update_increment *
-						 (size_t) ((view->lines - view->custom_lines) / update_increment)
-					       : view->lines - view->custom_lines));
+	if (!view_has_flags(view, VIEW_CUSTOM_STATUS) && view->line != NULL) {
+		struct line *line = &view->line[view->pos.lineno];
+		if (view_has_line(view, line) && line->lineno) {
+			wprintw(window, " - %s %u of %zu",
+						   view->ops->type,
+						   line->lineno,
+						   MAX(line->lineno,
+						       view->pipe
+						       ? update_increment *
+							 (size_t) ((view->lines - view->custom_lines) / update_increment)
+						       : view->lines - view->custom_lines));
+		}
 	}
 
 	if (view->pipe) {
@@ -729,7 +730,7 @@ update_view_title(struct view *view)
 
 	view_lines = view->pos.offset + view->height;
 	lines = view->lines ? MIN(view_lines, view->lines) * 100 / view->lines : 0;
-	mvwprintw(window, 0, view->width - count_digits(lines) - 1, "%u%%", lines);
+	mvwprintw(window, 0, view->width - count_digits(lines) - 2, " %u%%", lines);
 
 	wnoutrefresh(window);
 }
@@ -850,9 +851,10 @@ load_view(struct view *view, struct view *prev, enum open_flags flags)
 		 * the screen. */
 		werase(view->win);
 		/* Do not clear the position if it is the first view. */
-		if (view->prev && !(flags & (OPEN_RELOAD | OPEN_REFRESH)))
+		if (view->prev && !(flags & (OPEN_RELOAD | OPEN_REFRESH))) {
 			clear_position(&view->prev_pos);
-		report_clear();
+			report_clear();
+		}
 	} else if (view_is_displayed(view)) {
 		redraw_view(view);
 		report_clear();
